@@ -22,9 +22,11 @@ class Scene(object):
         if scene:
             self.name = scene.get('name')
             self.nodes = [gltf.nodes[i] for i in scene.get('nodes', [])]
+            self.extras = scene.get('extras', {})
         else:
             self.nodes = nodes or []
             self.name = name
+            self.extras = {}
 
     def __repr__(self):
         return self.name or super(Scene, self).__repr__()
@@ -35,6 +37,8 @@ class Scene(object):
             scene['name'] = self.name
         if self.nodes:
             scene['nodes'] = [gltf.index_node(n) for n in self.nodes]
+        if self.extras:
+            scene['extras'] = self.extras.copy()
         return scene
 
 
