@@ -183,10 +183,10 @@ class Image(object):
         """Return a PIL Image from this Image's data."""
         return PImage.open(self.get_fp())
 
-    def set_pil_image(self, pil_image, format="png"):
+    def set_pil_image(self, pil_image, format="png", quality=None):
         """Set the PIL Image data to this Image."""
         b = BytesIO()
-        pil_image.save(b, format=format)
+        pil_image.save(b, format=format, quality=quality)
         self.data = b.getvalue()
 
     def set_uri_to(self, folder):
