@@ -528,10 +528,10 @@ class Node(BaseGLTFStructure):
                 self.extensions = node['extensions']
 
             if 'extras' in node:
-                self.extras = node['extras']
+                self.extras = node['extras'].copy()
             
             if 'weights' in node:
-                self.weights= node['weights']
+                self.weights = node['weights']
 
             translation = node.get('translation')
             if translation:
